==> pireplay-0.0.2.tar.gz: pireplay-0.0.2/pireplay/replays.py <==
import os
from datetime import datetime

from pireplay.config import Config, config
from pireplay.consts import VIDEO_EXT


def capture_new_replay():
    replays_location = config(Config.replays_location)

    # remove latest replay if maximum number of kept replays reached
    kept_replays = [
        path for f in os.listdir(replays_location)
        if os.path.isfile(path := os.path.join(replays_location, f)) and
        f.endswith(VIDEO_EXT)
    ]
    if len(kept_replays) >= config(Config.kept_replays):
        oldest_replay = min(kept_replays, key=os.path.getctime)
        os.remove(oldest_replay)

    # save new replay
    replay_name = datetime.now().strftime(config(Config.replay_name))
    replay_path = os.path.join(replays_location, replay_name + VIDEO_EXT)

    # TODO get video file from camera and write it

    with open(replay_path, "w") as file:
        file.write("")

    return replay_name


def get_past_replays():
    replays_location = config(Config.replays_location)

    kept_replays = [
        f[:-len(VIDEO_EXT)]
        for f in os.listdir(replays_location)
        if os.path.isfile(os.path.join(replays_location, f)) and
        f.endswith(VIDEO_EXT)
    ]

    def replay_time(replay):
        path = os.path.join(replays_location, replay + VIDEO_EXT)
        return os.path.getctime(path)

    kept_replays.sort(key=replay_time, reverse=True)

    return kept_replays


def remove_replay(replay):
    path = os.path.join(config(Config.replays_location), replay + VIDEO_EXT)
    if not os.path.isfile(path):
        return False

    os.remove(path)

    return True

==> pireplay-0.1.0.tar.gz: pireplay-0.1.0/pireplay/replays.py <==
import os
from datetime import datetime

from pireplay.config import Config, config
from pireplay.consts import VIDEO_EXT, Option
from pireplay.camera import save_recording


def capture_new_replay():
    replays_location = config(Config.replays_location)

    # remove latest replay if maximum number of kept replays reached
    kept_replays = [
        path for f in os.listdir(replays_location)
        if os.path.isfile(path := os.path.join(replays_location, f)) and
        f.endswith(VIDEO_EXT)
    ]
    if len(kept_replays) >= int(config(Config.kept_replays)):
        oldest_replay = min(kept_replays, key=os.path.getctime)
        os.remove(oldest_replay)

    # save new replay
    replay_name = datetime.now().strftime(config(Config.replay_name))
    replay_path = os.path.join(replays_location, replay_name + VIDEO_EXT)
    replay_length = Option.capture_times_values[int(config(Config.capture_time_index))]

    save_recording(replay_path, replay_length)

    return replay_name


def get_past_replays():
    replays_location = config(Config.replays_location)

    kept_replays = [
        f[:-len(VIDEO_EXT)]
        for f in os.listdir(replays_location)
        if os.path.isfile(os.path.join(replays_location, f)) and
        f.endswith(VIDEO_EXT)
    ]

    def replay_time(replay):
        path = os.path.join(replays_location, replay + VIDEO_EXT)
        return os.path.getctime(path)

    kept_replays.sort(key=replay_time, reverse=True)

    return kept_replays


def remove_replay(replay):
    path = os.path.join(config(Config.replays_location), replay + VIDEO_EXT)
    if not os.path.isfile(path):
        return False

    os.remove(path)

    return True


def remove_all_replays():
    replays_dir = config(Config.replays_location)

    if not os.path.isdir(replays_dir):
        return False

    for filename in os.listdir(replays_dir):
        if filename.endswith(VIDEO_EXT):
            file_path = os.path.join(replays_dir, filename)
            os.remove(file_path)

    return True
